@@ -41,22 +41,36 @@ def plotmultiple(colnames,df,fz,plttype,orient='h',hue=None):
                 sns.swarmplot(df[i],orient=orient)
         elif(plttype=='hist'):
             if(hue!=None):
-                sns.distplot(df[hue],df[i],orient=orient)
+                sns.distplot(df[hue],df[i])
             else:
-                sns.distplot(df[i],orient=orient)
+                sns.distplot(df[i])
         else:
             sns.boxplot(df[i],orient=orient)
         c=c+1
     plt.tight_layout()
     plt.show()
 
-def draw_text(text,size,textcolor=(0,0,0),bkc=(255, 255, 255),bksize=(500,500)):
+def draw_text(text,size,textcolor='b',bkc=(255, 255, 255),bksize=(500,50)):
+    '''
+    text = string = Text to draw
+    size = int = font size of text to draw
+    textcolor : 'r','g','b','y'
+    bkc : (255,255,255) takes RGB value
+    bksize : length X width of figure
+    '''
     img = Image.new('RGB', bksize, color = bkc)
     font = ImageFont.truetype("arial",size)
     d = ImageDraw.Draw(img)
-    d.text((10,10), text,font=font,fill=textcolor)
+    c=(0,0,0)
+    if(textcolor=='r'):
+            c=(255,0,0)
+    elif(textcolor=='g'):
+            c=(0,128,0)
+    elif(textcolor=='b'):
+            c=(0,0,255)
+    elif(textcolor=='y'):
+            c=(255,255,0)
+    d.text((10,10), text,font=font,fill=c)
     plt.imshow(img)
-    plt.show()
-
-def calc(a,b):
-    return a+b
\ No newline at end of file
+    plt.axis(False)
+    plt.show()
\ No newline at end of file
